@@ -401,9 +401,6 @@ class Update(MethodsInterface):
         git = self.getGit()
         saved_host = dv.Get('cl_update_rep_hosting') if 'cl_update_rep_hosting' in dv.allVars else ''
         working_host = ''
-        a = dv.Get('cl_update_rep_url')
-        b = dv.Get('cl_update_rep_list')
-        c = dv.Get('cl_update_binhost_set')
         # проверка необходимости синхронизации других оверлеев
         if dv.Get("cl_update_inner_other_set") != 'auto':
             dv.Write("cl_update_other_set", dv.Get("cl_update_inner_other_set"), header="update")
@@ -1445,7 +1442,7 @@ class Update(MethodsInterface):
         return True
 
     def delete_binhost(self):
-        if not self.clVars.Get('update.cl_update_binhost_set'):
+        if not self.clVars.GetBool('update.cl_update_binhost_set'):
             self.clVars.Write('cl_update_binhost', ' ', location="system")
             try:
                 bin_cache_fn = self.get_bin_cache_filename()
